"""correcting std cms imaging templates

Revision ID: 6231bb30d95d
Revises: a832fcb74a8c
Create Date: 2021-06-30 11:04:35.628129

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "6231bb30d95d"
down_revision = "a832fcb74a8c"
branch_labels = None
depends_on = None

condor_content = """executable = std_cms_imaging.sh
arguments = metadata.json PPR.xml

output = imaging.out
error = imaging.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/conveyor, ./PPR.xml, ./metadata.json, $(CMS_PATH)/{{sdmId}}.ms

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

"""

script_content = """#!/bin/sh

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
mv {{sdmId}}.ms ./rawdata
./casa_envoy --standard-cmsimage $1 $2
./conveyor --deliver-image $1

"""

metadata_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}
"""


def upgrade():
    op.execute(
        f"""
        UPDATE capabilities
        SET capability_steps='prepare-and-run-workflow std_cms_imaging\nawait-workflow\nawait-qa' 
        WHERE capability_name='std_cms_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor_content}' WHERE filename='std_cms_imaging.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script_content}' WHERE filename='std_cms_imaging.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{metadata_content}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_condor_content}' WHERE filename='std_cms_imaging.condor'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_script_content}' WHERE filename='std_cms_imaging.sh'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_metadata_content}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
            """
    )


old_condor_content = """executable = std_cms_imaging.sh
arguments = metadata.json PPR.xml

output = imaging.out
error = imaging.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/spool/{{relative_path}}/working
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher,
 $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/conveyor, ./PPR.xml, ./metadata.json, $(CMS_PATH)/{{cms_name}}

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

"""


old_script_content = """#!/bin/sh

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
mv {{cms_name}} ./rawdata
./casa_envoy --standard-cmsimage $1 $2
./conveyor --deliver-image $1

"""

old_metadata_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
  "calibrationSourceDirectory":"{{cal_directory}}"
}
"""
